@@ -4,7 +4,6 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
-#include <QtGlobal>
 
 #ifdef Q_OS_ANDROID
 #include <QGuiApplication>
@@ -12,11 +11,15 @@
 #include <QApplication>
 #endif
 
+#include <QNetworkAccessManager>
+#include <QNetworkDiskCache>
 #include <QQmlApplicationEngine>
-#include <QtQml>
 #include <QUrl>
 #include <QQuickStyle>
+#include <QCommandLineParser>
+#include <QQmlContext>
 #include <QIcon>
+#include <QStandardPaths>
 #include <KLocalizedContext>
 #include <KLocalizedString>
 #include <KAboutData>
@@ -33,7 +36,9 @@
 
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#endif
 #ifdef Q_OS_ANDROID
     QGuiApplication app {argc, argv};
 #else
@@ -60,6 +65,14 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     QGuiApplication::setApplicationVersion(about.version());
     QGuiApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("org.kde.kongress")));
 
+    QNetworkAccessManager nam;
+    nam.setRedirectPolicy(QNetworkRequest::NoLessSafeRedirectPolicy);
+    nam.enableStrictTransportSecurityStore(true, QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QLatin1String("/hsts/"));
+    nam.setStrictTransportSecurityEnabled(true);
+    QNetworkDiskCache namDiskCache;
+    namDiskCache.setCacheDirectory(QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QLatin1String("/nam/"));
+    nam.setCache(&namDiskCache);
+
     qmlRegisterType<LocalCalendar>("org.kde.kongress", 0, 1, "LocalCalendar");
     qmlRegisterType<EventModel>("org.kde.kongress", 0, 1, "EventModel");
     qmlRegisterType<EventController>("org.kde.kongress", 0, 1, "EventController");
@@ -67,27 +80,18 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     qmlRegisterType<Conference>("org.kde.kongress", 0, 1, "Conference");
 
     qmlRegisterSingletonType<SettingsController>("org.kde.kongress", 0, 1, "SettingsController", &SettingsController::qmlInstance);
-    qmlRegisterSingletonType<ConferenceController>("org.kde.kongress", 0, 1, "ConferenceController", &ConferenceController::qmlInstance);;
 
-    static CalendarController *s_calendar_controller {nullptr};
-    static EventController *s_event_controller {nullptr};
-
-    qmlRegisterSingletonType<EventController>("org.kde.kongress", 0, 1, "EventController", [](QQmlEngine * engine, QJSEngine *) -> QObject * {
-        engine->setObjectOwnership(s_event_controller, QQmlEngine::CppOwnership);
-        return s_event_controller;
-    });
-
-    qmlRegisterSingletonType<CalendarController>("org.kde.kongress", 0, 1, "CalendarController", [](QQmlEngine * engine, QJSEngine *) -> QObject * {
-        engine->setObjectOwnership(s_calendar_controller, QQmlEngine::CppOwnership);
-        return s_calendar_controller;
-    });
+    ConferenceController conferenceController;
+    conferenceController.setNetworkAccessManager(&nam);
+    qmlRegisterSingletonInstance<ConferenceController>("org.kde.kongress", 0, 1, "ConferenceController", &conferenceController);
 
     CalendarController calendarController;
-    s_calendar_controller = &calendarController;
+    calendarController.setNetworkAccessManager(&nam);
+    qmlRegisterSingletonInstance<CalendarController>("org.kde.kongress", 0, 1, "CalendarController", &calendarController);
 
     EventController eventController;
     eventController.setCalendarController(&calendarController);
-    s_event_controller = &eventController;
+    qmlRegisterSingletonInstance<EventController>("org.kde.kongress", 0, 1, "EventController", &eventController);
 
 #ifdef Q_OS_ANDROID
     QQuickStyle::setStyle(QStringLiteral("Material"));
